@@ -8,7 +8,6 @@ from ._groups import (
     is_representation,
     is_group,
 )
-from ._linalg import intertwiners, has_rep_in_rep
 from ._reduce import germinate_formulas, reduce_permutation
 
 
@@ -21,8 +20,6 @@ __all__ = [
     "O3",
     "is_representation",
     "is_group",
-    "intertwiners",
-    "has_rep_in_rep",
     "germinate_formulas",
     "reduce_permutation",
 ]
