@@ -6,6 +6,7 @@ from ._gate import Gate
 from ._identity import Identity
 from ._s2act import S2Activation
 from ._normact import NormActivation
+from ._dropout import Dropout
 
 
 __all__ = [
@@ -18,4 +19,5 @@ __all__ = [
     "Identity",
     "S2Activation",
     "NormActivation",
+    "Dropout",
 ]
